@@ -83,7 +83,7 @@ def _convert_value(ptr):
     elif unqlite_value_is_int(ptr):
         return unqlite_value_to_int(ptr)
     elif unqlite_value_is_float(ptr):
-        return unqlite_value_to_float(ptr)
+        return unqlite_value_to_double(ptr)
     elif unqlite_value_is_bool(ptr):
         return bool(unqlite_value_to_bool(ptr))
     elif unqlite_value_is_null(ptr):
@@ -458,7 +458,9 @@ class DBCursorIterator(CursorIterator):
 
 class _ValueBase(object):
     def _set_value(self, ptr, python_value):
-        if isinstance(python_value, basestring):
+        if isinstance(python_value, unicode):
+            unqlite_value_string(ptr, python_value.encode('utf-8'), -1)
+        elif isinstance(python_value, basestring):
             unqlite_value_string(ptr, python_value, -1)
         elif isinstance(python_value, (list, tuple)):
             for item in python_value:
